@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import with_statement
 import unittest
-import contextlib
 import itertools
 try:
     import json
@@ -47,7 +45,7 @@ class TestProject(unittest.TestCase):
                 ['proj1.res1', ],
                 ['proj1.res1', ],
                 ['transifex.txn', 'transifex.txo', ],
-                ['proj1.res1', 'proj2.res2', 'transifex.txn', 'transifex.txo', ],
+                ['proj1.res1', 'proj2.res2', 'transifex.txn', 'transifex.txo', ],  # noqa
                 ['transifex.txo', ],
                 ['transifex.txn', 'transifex.txo', ],
                 ['transifex.txn', ],
@@ -75,82 +73,132 @@ class TestProjectMinimumPercent(unittest.TestCase):
     def test_cmd_option(self):
         """Test command-line option."""
         self.p.minimum_perc = 20
-        results = itertools.cycle([80, 90 ])
+        results = itertools.cycle([80, 90])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertFalse(self.p._satisfies_min_translated({'completed': '12%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '20%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '30%'}))
+            self.assertFalse(
+                self.p._satisfies_min_translated({'completed': '12%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '20%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '30%'})
+            )
 
     def test_global_only(self):
         """Test only global option."""
-        results = itertools.cycle([80, None ])
+        results = itertools.cycle([80, None])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertFalse(self.p._satisfies_min_translated({'completed': '70%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '80%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '90%'}))
+            self.assertFalse(
+                self.p._satisfies_min_translated({'completed': '70%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '80%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '90%'})
+            )
 
     def test_local_lower_than_global(self):
         """Test the case where the local option is lower than the global."""
-        results = itertools.cycle([80, 70 ])
+        results = itertools.cycle([80, 70])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertFalse(self.p._satisfies_min_translated({'completed': '60%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '70%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '80%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '90%'}))
+            self.assertFalse(
+                self.p._satisfies_min_translated({'completed': '60%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '70%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '80%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '90%'})
+            )
 
     def test_local_higher_than_global(self):
         """Test the case where the local option is lower than the global."""
-        results = itertools.cycle([60, 70 ])
+        results = itertools.cycle([60, 70])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertFalse(self.p._satisfies_min_translated({'completed': '60%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '70%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '80%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '90%'}))
+            self.assertFalse(
+                self.p._satisfies_min_translated({'completed': '60%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '70%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '80%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '90%'})
+            )
 
     def test_local_only(self):
         """Test the case where the local option is lower than the global."""
-        results = itertools.cycle([None, 70 ])
+        results = itertools.cycle([None, 70])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertFalse(self.p._satisfies_min_translated({'completed': '60%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '70%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '80%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '90%'}))
+            self.assertFalse(
+                self.p._satisfies_min_translated({'completed': '60%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '70%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '80%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '90%'})
+            )
 
     def test_no_option(self):
         """"Test the case there is nothing defined."""
-        results = itertools.cycle([None, None ])
+        results = itertools.cycle([None, None])
+
         def side_effect(*args):
-            return results.next()
+            return next(results)
 
         with patch.object(self.p, "get_resource_option") as mock:
             mock.side_effect = side_effect
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '0%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '10%'}))
-            self.assertTrue(self.p._satisfies_min_translated({'completed': '90%'}))
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '0%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '10%'})
+            )
+            self.assertTrue(
+                self.p._satisfies_min_translated({'completed': '90%'})
+            )
 
 
 class TestProjectFilters(unittest.TestCase):
-    """Test filters used to decide whether to push/pull a translation or not."""
+    """
+    Test filters used to decide whether to push/pull a translation or not.
+    """
 
     def setUp(self):
         super(TestProjectFilters, self).setUp()
@@ -166,7 +214,7 @@ class TestProjectFilters(unittest.TestCase):
                 'completed': '70%', 'last_update': '2011-11-01 15:00:00',
             },
         }
-        self.langs = self.stats.keys()
+        self.langs = list(self.stats.keys())
 
     def test_add_translation(self):
         """Test filters for adding translations.
@@ -215,8 +263,9 @@ class TestProjectFilters(unittest.TestCase):
             # older local files
             local_times = [self.p._generate_timestamp('2011-11-01 14:00:59')]
             results = itertools.cycle(local_times)
+
             def side_effect(*args):
-                return results.next()
+                return next(results)
 
             with patch.object(self.p, "_get_time_of_local_file") as time_mock:
                 time_mock.side_effect = side_effect
@@ -230,8 +279,9 @@ class TestProjectFilters(unittest.TestCase):
             # newer local files
             local_times = [self.p._generate_timestamp('2011-11-01 15:01:59')]
             results = itertools.cycle(local_times)
+
             def side_effect(*args):
-                return results.next()
+                return next(results)
 
             with patch.object(self.p, "_get_time_of_local_file") as time_mock:
                 time_mock.side_effect = side_effect
@@ -243,7 +293,9 @@ class TestProjectFilters(unittest.TestCase):
                         )
 
     def test_push_translation(self):
-        """Test filters for pushing a translation file."""
+        """
+        Test filters for pushing a translation file.
+        """
         with patch.object(self.p, "get_resource_option") as mock:
             mock.return_value = None
 
@@ -251,9 +303,13 @@ class TestProjectFilters(unittest.TestCase):
             should_push = self.p._should_push_translation
             force = True
             for lang in self.langs:
-                self.assertTrue(should_push(lang, self.stats, local_file, force))
+                self.assertTrue(
+                    should_push(
+                        lang, self.stats, local_file, force
+                    )
+                )
 
-            force = False       # reminder
+            force = False  # reminder
 
             # unknown language
             self.assertTrue(should_push('es', self.stats, local_file))
@@ -261,8 +317,9 @@ class TestProjectFilters(unittest.TestCase):
             # older local files
             local_times = [self.p._generate_timestamp('2011-11-01 14:00:59')]
             results = itertools.cycle(local_times)
+
             def side_effect(*args):
-                return results.next()
+                return next(results)
 
             with patch.object(self.p, "_get_time_of_local_file") as time_mock:
                 time_mock.side_effect = side_effect
@@ -276,8 +333,9 @@ class TestProjectFilters(unittest.TestCase):
             # newer local files
             local_times = [self.p._generate_timestamp('2011-11-01 15:01:59')]
             results = itertools.cycle(local_times)
+
             def side_effect(*args):
-                return results.next()
+                return next(results)
 
             with patch.object(self.p, "_get_time_of_local_file") as time_mock:
                 time_mock.side_effect = side_effect
@@ -309,8 +367,8 @@ class TestProjectPull(unittest.TestCase):
                 'completed': '70%', 'last_update': '2011-11-01 15:00:00',
             },
         }
-        self.langs = self.stats.keys()
-        self.files = dict(zip(self.langs, itertools.repeat(None)))
+        self.langs = list(self.stats.keys())
+        self.files = dict(list(zip(self.langs, itertools.repeat(None))))
         self.details = {'available_languages': []}
         for lang in self.langs:
             self.details['available_languages'].append({'code': lang})
@@ -320,27 +378,29 @@ class TestProjectPull(unittest.TestCase):
     def test_new_translations(self):
         """Test finding new transaltions to add."""
         with patch.object(self.p, 'do_url_request') as resource_mock:
-            resource_mock.return_value = json.dumps(self.details)
+            resource_mock.return_value = json.dumps(self.details), "utf-8"
             files_keys = self.langs
             new_trans = self.p._new_translations_to_add
             for force in [True, False]:
                 res = new_trans(
                     self.files, self.slang, self.lang_map, self.stats, force
                 )
-                self.assertEquals(res, set([]))
+                self.assertEqual(res, set([]))
 
-            with patch.object(self.p, '_should_add_translation') as filter_mock:
+            with patch.object(self.p,
+                              '_should_add_translation') as filter_mock:
                 filter_mock.return_value = True
                 for force in [True, False]:
                     res = new_trans(
-                        {'el': None}, self.slang, self.lang_map, self.stats, force
+                        {'el': None}, self.slang, self.lang_map, self.stats,
+                        force
                     )
-                    self.assertEquals(res, set(['pt']))
+                    self.assertEqual(res, set(['pt']))
                 for force in [True, False]:
                     res = new_trans(
                         {}, self.slang, self.lang_map, self.stats, force
                     )
-                    self.assertEquals(res, set(['el', 'pt']))
+                    self.assertEqual(res, set(['el', 'pt']))
 
                 files = {}
                 files['pt_PT'] = None
@@ -349,7 +409,16 @@ class TestProjectPull(unittest.TestCase):
                     res = new_trans(
                         files, self.slang, lang_map, self.stats, force
                     )
-                    self.assertEquals(res, set(['el']))
+                    self.assertEqual(res, set(['el']))
+
+    def test_get_pseudo_file(self):
+        slang = 'en'
+        resource = 'adriana'
+        file_filter = 'adriana/<lang>.po'
+
+        pseudo_file = self.p._get_pseudo_file(slang, resource, file_filter)
+
+        self.assertEqual(pseudo_file, 'adriana/en_pseudo.po')
 
     def test_languages_to_pull_empty_initial_list(self):
         """Test determining the languages to pull, when the initial
@@ -363,7 +432,7 @@ class TestProjectPull(unittest.TestCase):
         )
         existing = res[0]
         new = res[1]
-        self.assertEquals(existing, set(['el', 'en', 'pt']))
+        self.assertEqual(existing, set(['el', 'en', 'pt']))
         self.assertFalse(new)
 
         del self.files['el']
@@ -374,7 +443,7 @@ class TestProjectPull(unittest.TestCase):
         )
         existing = res[0]
         new = res[1]
-        self.assertEquals(existing, set(['el', 'en', 'pt']))
+        self.assertEqual(existing, set(['el', 'en', 'pt']))
         self.assertFalse(new)
 
     def test_languages_to_pull_with_initial_list(self):
@@ -394,7 +463,7 @@ class TestProjectPull(unittest.TestCase):
             )
             existing = res[0]
             new = res[1]
-            self.assertEquals(existing, set(['en', 'el-gr', ]))
+            self.assertEqual(existing, set(['en', 'el-gr', ]))
             self.assertFalse(new)
 
             mock.return_value = False
@@ -403,7 +472,7 @@ class TestProjectPull(unittest.TestCase):
             )
             existing = res[0]
             new = res[1]
-            self.assertEquals(existing, set(['en', 'el-gr', ]))
+            self.assertEqual(existing, set(['en', 'el-gr', ]))
             self.assertFalse(new)
 
             del self.files['el-gr']
@@ -413,8 +482,8 @@ class TestProjectPull(unittest.TestCase):
             )
             existing = res[0]
             new = res[1]
-            self.assertEquals(existing, set(['en', ]))
-            self.assertEquals(new, set(['el', ]))
+            self.assertEqual(existing, set(['en', ]))
+            self.assertEqual(new, set(['el', ]))
 
             mock.return_value = False
             res = self.p._languages_to_pull(
@@ -422,8 +491,8 @@ class TestProjectPull(unittest.TestCase):
             )
             existing = res[0]
             new = res[1]
-            self.assertEquals(existing, set(['en', ]))
-            self.assertEquals(new, set([]))
+            self.assertEqual(existing, set(['en', ]))
+            self.assertEqual(new, set([]))
 
     def test_in_combination_with_force_option(self):
         """Test the minumum-perc option along with -f."""
@@ -431,22 +500,22 @@ class TestProjectPull(unittest.TestCase):
             mock.return_value = 70
 
             res = self.p._should_download('de', self.stats, None, False)
-            self.assertEquals(res, False)
+            self.assertEqual(res, False)
             res = self.p._should_download('el', self.stats, None, False)
-            self.assertEquals(res, False)
+            self.assertEqual(res, False)
             res = self.p._should_download('el', self.stats, None, True)
-            self.assertEquals(res, False)
+            self.assertEqual(res, False)
             res = self.p._should_download('en', self.stats, None, False)
-            self.assertEquals(res, True)
+            self.assertEqual(res, True)
             res = self.p._should_download('en', self.stats, None, True)
-            self.assertEquals(res, True)
+            self.assertEqual(res, True)
 
             with patch.object(self.p, '_remote_is_newer') as local_file_mock:
                 local_file_mock = False
                 res = self.p._should_download('pt', self.stats, None, False)
-                self.assertEquals(res, True)
+                self.assertEqual(res, True)
                 res = self.p._should_download('pt', self.stats, None, True)
-                self.assertEquals(res, True)
+                self.assertEqual(res, True)
 
 
 class TestFormats(unittest.TestCase):
@@ -463,10 +532,10 @@ class TestFormats(unittest.TestCase):
         }
         extensions = ['.po', '.ts', '', ]
         with patch.object(self.p, "do_url_request") as mock:
-            mock.return_value = json.dumps(sample_formats)
+            mock.return_value = json.dumps(sample_formats), "utf-8"
             for (type_, ext) in zip(['PO', 'QT', 'NONE', ], extensions):
                 extension = self.p._extension_for(type_)
-                self.assertEquals(extension, ext)
+                self.assertEqual(extension, ext)
 
 
 class TestOptions(unittest.TestCase):
@@ -477,20 +546,18 @@ class TestOptions(unittest.TestCase):
 
     def test_get_option(self):
         """Test _get_option method."""
-        with contextlib.nested(
-            patch.object(self.p, 'get_resource_option'),
-            patch.object(self.p, 'config', create=True)
-        ) as (rmock, cmock):
-            rmock.return_value = 'resource'
-            cmock.has_option.return_value = 'main'
-            cmock.get.return_value = 'main'
-            self.assertEqual(self.p._get_option(None, None), 'resource')
-            rmock.return_value = None
-            cmock.has_option.return_value = 'main'
-            cmock.get.return_value = 'main'
-            self.assertEqual(self.p._get_option(None, None), 'main')
-            cmock.has_option.return_value = None
-            self.assertIs(self.p._get_option(None, None), None)
+        with patch.object(self.p, 'get_resource_option') as rmock:
+            with patch.object(self.p, 'config', create=True) as cmock:
+                rmock.return_value = 'resource'
+                cmock.has_option.return_value = 'main'
+                cmock.get.return_value = 'main'
+                self.assertEqual(self.p._get_option(None, None), 'resource')
+                rmock.return_value = None
+                cmock.has_option.return_value = 'main'
+                cmock.get.return_value = 'main'
+                self.assertEqual(self.p._get_option(None, None), 'main')
+                cmock.has_option.return_value = None
+                self.assertIs(self.p._get_option(None, None), None)
 
 
 class TestConfigurationOptions(unittest.TestCase):
@@ -503,15 +570,15 @@ class TestConfigurationOptions(unittest.TestCase):
         with patch.object(p, 'config', create=True) as config_mock:
             p.set_i18n_type([], i18n_type)
             calls = config_mock.method_calls
-            self.assertEquals('set', calls[0][0])
-            self.assertEquals('main', calls[0][1][0])
+            self.assertEqual('set', calls[0][0])
+            self.assertEqual('main', calls[0][1][0])
             p.set_i18n_type(['transifex.txo'], 'PO')
             calls = config_mock.method_calls
-            self.assertEquals('set', calls[0][0])
+            self.assertEqual('set', calls[0][0])
             p.set_i18n_type(['transifex.txo', 'transifex.txn'], 'PO')
             calls = config_mock.method_calls
-            self.assertEquals('set', calls[0][0])
-            self.assertEquals('set', calls[1][0])
+            self.assertEqual('set', calls[0][0])
+            self.assertEqual('set', calls[1][0])
 
 
 class TestStats(unittest.TestCase):
@@ -528,4 +595,3 @@ class TestStats(unittest.TestCase):
         self.stats.__getitem__.assert_called_with('completed')
         Project._extract_completed(self.stats, 'reviewed')
         self.stats.__getitem__.assert_called_with('reviewed_percentage')
-
