@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-In this file we have all the top level commands for the transifex client.
+"""In this file we have all the top level commands for the transifex client.
 Since we're using a way to automatically list them and execute them, when
 adding code to this file you must take care of the following:
  * Added functions must begin with 'cmd_' followed by the actual name of the
@@ -16,24 +15,30 @@ adding code to this file you must take care of the following:
    descripition field.
 """
 import os
-import re, shutil
+import re
+import shutil
 import sys
 from optparse import OptionParser, OptionGroup
-import ConfigParser
 
+try:
+    import configparser
+except ImportError:
+    import ConfigParser as configparser
+
+from six.moves import input
 
 from txclib import utils, project
 from txclib.utils import parse_json, compile_json, files_in_project
 from txclib.config import OrderedRawConfigParser
 from txclib.exceptions import UnInitializedError
 from txclib.parsers import delete_parser, help_parser, parse_csv_option, \
-        status_parser, pull_parser, set_parser, push_parser, init_parser
+    status_parser, pull_parser, set_parser, push_parser, init_parser
 from txclib.paths import posix_path
 from txclib.log import logger
 
 
 def cmd_init(argv, path_to_tx):
-    "Initialize a new transifex project."
+    """Initialize a new transifex project."""
     parser = init_parser()
     (options, args) = parser.parse_args(argv)
     if len(args) > 1:
@@ -43,11 +48,14 @@ def cmd_init(argv, path_to_tx):
     else:
         path_to_tx = os.getcwd()
 
-    if os.path.isdir(os.path.join(path_to_tx,".tx")):
+    if os.path.isdir(os.path.join(path_to_tx, ".tx")):
         logger.info("tx: There is already a tx folder!")
-        reinit = raw_input("Do you want to delete it and reinit the project? [y/N]: ")
-        while (reinit != 'y' and reinit != 'Y' and reinit != 'N' and reinit != 'n' and reinit != ''):
-            reinit = raw_input("Do you want to delete it and reinit the project? [y/N]: ")
+        reinit = input("Do you want to delete it and "
+                       "reinit the project? [y/N]: ")
+        while (reinit != 'y' and reinit != 'Y' and reinit != 'N'
+               and reinit != 'n' and reinit != ''):
+            reinit = input("Do you want to delete it and "
+                           "reinit the project? [y/N]: ")
         if not reinit or reinit in ['N', 'n', 'NO', 'no', 'No']:
             return
         # Clean the old settings
@@ -57,7 +65,7 @@ def cmd_init(argv, path_to_tx):
             shutil.rmtree(rm_dir)
 
     logger.info("Creating .tx folder...")
-    os.mkdir(os.path.join(path_to_tx,".tx"))
+    os.mkdir(os.path.join(path_to_tx, ".tx"))
 
     # Handle the credentials through transifexrc
     home = os.path.expanduser("~")
@@ -65,7 +73,8 @@ def cmd_init(argv, path_to_tx):
     config = OrderedRawConfigParser()
 
     default_transifex = "https://www.transifex.com"
-    transifex_host = options.host or raw_input("Transifex instance [%s]: " % default_transifex)
+    transifex_host = options.host or input("Transifex instance [%s]: " %
+                                           default_transifex)
 
     if not transifex_host:
         transifex_host = default_transifex
@@ -87,13 +96,13 @@ def cmd_init(argv, path_to_tx):
 
     prj = project.Project(path_to_tx)
     prj.getset_host_credentials(transifex_host, user=options.user,
-        password=options.password)
+                                password=options.password)
     prj.save()
     logger.info("Done.")
 
 
 def cmd_set(argv, path_to_tx):
-    "Add local or remote files under transifex"
+    """Add local or remote files under transifex"""
     parser = set_parser()
     (options, args) = parser.parse_args(argv)
 
@@ -108,17 +117,19 @@ def cmd_set(argv, path_to_tx):
             parser.error("Please specify a resource")
         if not options.source_language:
             parser.error("Please specify a source language.")
-        if not '<lang>' in expression:
+        if '<lang>' not in expression:
             parser.error("The expression you have provided is not valid.")
         if not utils.valid_slug(options.resource):
-            parser.error("Invalid resource slug. The format is <project_slug>"\
-                ".<resource_slug> and the valid characters include [_-\w].")
+            parser.error("Invalid resource slug. The format is <project_slug>"
+                         ".<resource_slug> and the valid characters include"
+                         " [_-\w].")
         _auto_local(path_to_tx, options.resource,
-            source_language=options.source_language,
-            expression = expression, source_file=options.source_file,
-            execute=options.execute, regex=False)
+                    source_language=options.source_language,
+                    expression=expression, source_file=options.source_file,
+                    execute=options.execute, regex=False)
         if options.execute:
-            _set_minimum_perc(options.resource, options.minimum_perc, path_to_tx)
+            _set_minimum_perc(options.resource, options.minimum_perc,
+                              path_to_tx)
             _set_mode(options.resource, options.mode, path_to_tx)
             _set_type(options.resource, options.i18n_type, path_to_tx)
         return
@@ -136,8 +147,8 @@ def cmd_set(argv, path_to_tx):
     if options.is_source:
         resource = options.resource
         if not resource:
-            parser.error("You must specify a resource name with the"
-                " -r|--resource flag.")
+            parser.error("You must specify a resource name with the "
+                         "-r|--resource flag.")
 
         lang = options.language
         if not lang:
@@ -147,8 +158,9 @@ def cmd_set(argv, path_to_tx):
             parser.error("Please specify a file.")
 
         if not utils.valid_slug(resource):
-            parser.error("Invalid resource slug. The format is <project_slug>"\
-                ".<resource_slug> and the valid characters include [_-\w].")
+            parser.error("Invalid resource slug. The format is <project_slug>"
+                         ".<resource_slug> and the valid characters include "
+                         "[_-\w].")
 
         file = args[0]
         # Calculate relative path
@@ -166,13 +178,14 @@ def cmd_set(argv, path_to_tx):
 
         try:
             _go_to_dir(path_to_tx)
-        except UnInitializedError, e:
+        except UnInitializedError as e:
             utils.logger.error(e)
             return
 
         if not utils.valid_slug(resource):
-            parser.error("Invalid resource slug. The format is <project_slug>"\
-                ".<resource_slug> and the valid characters include [_-\w].")
+            parser.error("Invalid resource slug. The format is <project_slug>"
+                         ".<resource_slug> and the valid characters include "
+                         "[_-\w].")
         _set_translation(path_to_tx, resource, lang, path_to_file)
 
     _set_mode(options.resource, options.mode, path_to_tx)
@@ -183,8 +196,8 @@ def cmd_set(argv, path_to_tx):
     return
 
 
-def _auto_local(path_to_tx, resource, source_language, expression, execute=False,
-                source_file=None, regex=False):
+def _auto_local(path_to_tx, resource, source_language, expression,
+                execute=False, source_file=None, regex=False):
     """Auto configure local project."""
     # The path everything will be relative to
     curpath = os.path.abspath(os.curdir)
@@ -195,7 +208,7 @@ def _auto_local(path_to_tx, resource, source_language, expression, execute=False
 
     if not execute:
         logger.info("Only printing the commands which will be run if the "
-                  "--execute switch is specified.")
+                    "--execute switch is specified.")
 
     # First, let's construct a dictionary of all matching files.
     # Note: Only the last matching file of a language will be stored.
@@ -210,14 +223,16 @@ def _auto_local(path_to_tx, resource, source_language, expression, execute=False
                 translation_files[lang] = f_path
 
     if not source_file:
-        raise Exception("Could not find a source language file. Please run"
-            " set --source manually and then re-run this command or provide"
-            " the source file with the -s flag.")
+        raise Exception("Could not find a source language file. Please run "
+                        "set --source manually and then re-run this command "
+                        "or provide the source file with the -s flag.")
     if execute:
-        logger.info("Updating source for resource %s ( %s -> %s )." % (resource,
-            source_language, os.path.relpath(source_file, path_to_tx)))
+        logger.info("Updating source for resource %s ( %s -> %s )." % (
+                    resource, source_language, os.path.relpath(
+                        source_file, path_to_tx)
+                    ))
         _set_source_file(path_to_tx, resource, source_language,
-            os.path.relpath(source_file, path_to_tx))
+                         os.path.relpath(source_file, path_to_tx))
     else:
         logger.info('\ntx set --source -r %(res)s -l %(lang)s %(file)s\n' % {
             'res': resource,
@@ -230,14 +245,15 @@ def _auto_local(path_to_tx, resource, source_language, expression, execute=False
     if execute:
         try:
             prj.config.get("%s" % resource, "source_file")
-        except ConfigParser.NoSectionError:
-            raise Exception("No resource with slug \"%s\" was found.\nRun 'tx set --auto"
-                "-local -r %s \"expression\"' to do the initial configuration." % resource)
+        except configparser.NoSectionError:
+            raise Exception("No resource with slug \"%s\" was found.\nRun "
+                            "'tx set --auto-local -r %s \"expression\"' to "
+                            "do the initial configuration." % resource)
 
     # Now let's handle the translation files.
     if execute:
-        logger.info("Updating file expression for resource %s ( %s )." % (resource,
-            expression))
+        logger.info("Updating file expression for resource %s ( %s )." % (
+                    resource, expression))
         # Eval file_filter relative to root dir
         file_filter = posix_path(
             os.path.relpath(os.path.join(curpath, expression), path_to_tx)
@@ -255,64 +271,71 @@ def _auto_local(path_to_tx, resource, source_language, expression, execute=False
 
 
 def _auto_remote(path_to_tx, url):
-    """
-    Initialize a remote release/project/resource to the current directory.
-    """
+    """Initialize a remote project/resource to the current directory."""
     logger.info("Auto configuring local project from remote URL...")
 
     type, vars = utils.parse_tx_url(url)
     prj = project.Project(path_to_tx)
     username, password = prj.getset_host_credentials(vars['hostname'])
 
-    if type == 'project':
+    if type.startswith('project'):
         logger.info("Getting details for project %s" % vars['project'])
-        proj_info = utils.get_details('project_details',
+        proj_info = utils.get_details(
+            'project_details',
             username, password,
-            hostname = vars['hostname'], project = vars['project'])
-        resources = [ '.'.join([vars['project'], r['slug']]) for r in proj_info['resources'] ]
+            hostname=vars['hostname'],
+            project=vars['project'])
+        resources = ['.'.join([vars['project'],
+                     r['slug']]) for r in proj_info['resources']]
         logger.info("%s resources found. Configuring..." % len(resources))
     elif type == 'release':
         logger.info("Getting details for release %s" % vars['release'])
-        rel_info = utils.get_details('release_details',
-            username, password, hostname = vars['hostname'],
-            project = vars['project'], release = vars['release'])
+        rel_info = utils.get_details(
+            'release_details',
+            username, password,
+            hostname=vars['hostname'],
+            project=vars['project'],
+            release=vars['release'])
         resources = []
         for r in rel_info['resources']:
-            if r.has_key('project'):
+            if 'project' in r:
                 resources.append('.'.join([r['project']['slug'], r['slug']]))
             else:
                 resources.append('.'.join([vars['project'], r['slug']]))
         logger.info("%s resources found. Configuring..." % len(resources))
-    elif type == 'resource':
+    elif type.startswith('resource'):
         logger.info("Getting details for resource %s" % vars['resource'])
-        resources = [ '.'.join([vars['project'], vars['resource']]) ]
+        resources = ['.'.join([vars['project'], vars['resource']])]
     else:
-        raise("Url '%s' is not recognized." % url)
+        raise Exception("Url '%s' is not recognized." % url)
 
     for resource in resources:
         logger.info("Configuring resource %s." % resource)
         proj, res = resource.split('.')
-        res_info = utils.get_details('resource_details',
-             username, password, hostname = vars['hostname'],
-             project = proj, resource=res)
+        res_info = utils.get_details(
+            'resource_details',
+            username, password,
+            hostname=vars['hostname'],
+            project=proj, resource=res)
         try:
             source_lang = res_info['source_language_code']
             i18n_type = res_info['i18n_type']
         except KeyError:
-            raise Exception("Remote server seems to be running an unsupported version"
-                " of Transifex. Either update your server software of fallback"
-                " to a previous version of transifex-client.")
+            raise Exception("Remote server seems to be running an unsupported "
+                            "version of Transifex. Either update your server "
+                            "software of fallback to a previous version "
+                            "of transifex-client.")
         prj.set_remote_resource(
             resource=resource,
-            host = vars['hostname'],
-            source_lang = source_lang,
-            i18n_type = i18n_type)
+            host=vars['hostname'],
+            source_lang=source_lang,
+            i18n_type=i18n_type)
 
     prj.save()
 
 
 def cmd_push(argv, path_to_tx):
-    "Push local files to remote server"
+    """Push local files to remote server"""
     parser = push_parser()
     (options, args) = parser.parse_args(argv)
     force_creation = options.force_creation
@@ -321,8 +344,8 @@ def cmd_push(argv, path_to_tx):
     skip = options.skip_errors
     prj = project.Project(path_to_tx)
     if not (options.push_source or options.push_translations):
-        parser.error("You need to specify at least one of the -s|--source,"
-            " -t|--translations flags with the push command.")
+        parser.error("You need to specify at least one of the -s|--source, "
+                     "-t|--translations flags with the push command.")
 
     prj.push(
         force=force_creation, resources=resources, languages=languages,
@@ -334,12 +357,12 @@ def cmd_push(argv, path_to_tx):
 
 
 def cmd_pull(argv, path_to_tx):
-    "Pull files from remote server to local repository"
+    """Pull files from remote server to local repository"""
     parser = pull_parser()
     (options, args) = parser.parse_args(argv)
     if options.fetchall and options.languages:
-        parser.error("You can't user a language filter along with the"\
-            " -a|--all option")
+        parser.error("You can't user a language filter along with the "
+                     "-a|--all option")
     languages = parse_csv_option(options.languages)
     resources = parse_csv_option(options.resources)
     pseudo = options.pseudo
@@ -348,7 +371,7 @@ def cmd_pull(argv, path_to_tx):
 
     try:
         _go_to_dir(path_to_tx)
-    except UnInitializedError, e:
+    except UnInitializedError as e:
         utils.logger.error(e)
         return
 
@@ -367,21 +390,22 @@ def _set_source_file(path_to_tx, resource, lang, path_to_file):
     """Reusable method to set source file."""
     proj, res = resource.split('.')
     if not proj or not res:
-        raise Exception("\"%s.%s\" is not a valid resource identifier. It should"
-            " be in the following format project_slug.resource_slug." %
-            (proj, res))
+        raise Exception("\"%s.%s\" is not a valid resource identifier. "
+                        "It should be in the following format "
+                        "project_slug.resource_slug." %
+                        (proj, res))
     if not lang:
         raise Exception("You haven't specified a source language.")
 
     try:
         _go_to_dir(path_to_tx)
-    except UnInitializedError, e:
+    except UnInitializedError as e:
         utils.logger.error(e)
         return
 
     if not os.path.exists(path_to_file):
         raise Exception("tx: File ( %s ) does not exist." %
-            os.path.join(path_to_tx, path_to_file))
+                        os.path.join(path_to_tx, path_to_file))
 
     # instantiate the project.Project
     prj = project.Project(path_to_tx)
@@ -401,9 +425,9 @@ def _set_source_file(path_to_tx, resource, lang, path_to_file):
     try:
         try:
             prj.config.get("%s.%s" % (proj, res), "source_file")
-        except ConfigParser.NoSectionError:
+        except configparser.NoSectionError:
             prj.config.add_section("%s.%s" % (proj, res))
-        except ConfigParser.NoOptionError:
+        except configparser.NoOptionError:
             pass
     finally:
         prj.config.set(
@@ -419,13 +443,14 @@ def _set_translation(path_to_tx, resource, lang, path_to_file):
 
     proj, res = resource.split('.')
     if not project or not resource:
-        raise Exception("\"%s\" is not a valid resource identifier. It should"
-            " be in the following format project_slug.resource_slug." %
-            resource)
+        raise Exception("\"%s\" is not a valid resource identifier. "
+                        "It should be in the following format "
+                        "project_slug.resource_slug." %
+                        resource)
 
     try:
         _go_to_dir(path_to_tx)
-    except UnInitializedError, e:
+    except UnInitializedError as e:
         utils.logger.error(e)
         return
 
@@ -440,12 +465,13 @@ def _set_translation(path_to_tx, resource, lang, path_to_file):
     if root_dir not in os.path.normpath(os.path.abspath(path_to_file)):
         raise Exception("File must be under the project root directory.")
 
-    if lang ==  prj.config.get("%s.%s" % (proj, res), "source_lang"):
-        raise Exception("tx: You cannot set translation file for the source language."
-            " Source languages contain the strings which will be translated!")
+    if lang == prj.config.get("%s.%s" % (proj, res), "source_lang"):
+        raise Exception("tx: You cannot set translation file for "
+                        "the source language. Source languages contain "
+                        "the strings which will be translated!")
 
-    logger.info("Updating translations for resource %s ( %s -> %s )." % (resource,
-        lang, path_to_file))
+    logger.info("Updating translations for resource %s ( %s -> %s )." % (
+                resource, lang, path_to_file))
     path_to_file = os.path.relpath(path_to_file, root_dir)
     prj.config.set(
         "%s.%s" % (proj, res), "trans.%s" % lang, posix_path(path_to_file)
@@ -455,7 +481,7 @@ def _set_translation(path_to_tx, resource, lang, path_to_file):
 
 
 def cmd_status(argv, path_to_tx):
-    "Print status of current project"
+    """Print status of current project"""
     parser = status_parser()
     (options, args) = parser.parse_args(argv)
     resources = parse_csv_option(options.resources)
@@ -470,16 +496,16 @@ def cmd_status(argv, path_to_tx):
         sfile = prj.get_resource_option(res, 'source_file') or "N/A"
         lang_map = prj.get_resource_lang_mapping(res)
         logger.info(" - %s: %s (%s)" % (utils.color_text(slang, "RED"),
-            sfile, utils.color_text("source", "YELLOW")))
+                    sfile, utils.color_text("source", "YELLOW")))
         files = prj.get_resource_files(res)
-        fkeys = files.keys()
+        fkeys = list(files.keys())
         fkeys.sort()
         for lang in fkeys:
             local_lang = lang
-            if lang in lang_map.values():
+            if lang in list(lang_map.values()):
                 local_lang = lang_map.flip[lang]
             logger.info(" - %s: %s" % (utils.color_text(local_lang, "RED"),
-                files[lang]))
+                        files[lang]))
         logger.info("")
 
 
@@ -504,18 +530,18 @@ def cmd_help(argv, path_to_tx):
     # the code below will only be executed if the KeyError exception is thrown
     # becuase in all other cases the function called with --help will exit
     # instead of return here
-    keys = fns.keys()
+    keys = list(fns.keys())
     keys.sort()
 
     logger.info("Transifex command line client.\n")
     logger.info("Available commands are:")
     for key in keys:
-        logger.info("  %-15s\t%s" % (key, fns[key].func_doc))
+        logger.info("  %-15s\t%s" % (key, getattr(fns[key], '__doc__')))
     logger.info("\nFor more information run %s command --help" % sys.argv[0])
 
 
 def cmd_delete(argv, path_to_tx):
-    "Delete an accessible resource or translation in a remote server."
+    """Delete an accessible resource or translation in a remote server."""
     parser = delete_parser()
     (options, args) = parser.parse_args(argv)
     languages = parse_csv_option(options.languages)
